class Message < ApplicationRecord
  belongs_to :user
  has_many :message_topics, dependent: :delete_all
  validates :text, length: { maximum: 140 }

  after_save :regenerate_topics

  def self.topic_of(topic)
    Message.joins(:message_topics).where(message_topics: { topic: topic })
  end

  def split_full
    text.split(/([ 　,.、。])/)
  end

  def split(full: true)
    if full
      text.split(/([ 　,.、。])/)
    else
      text.split(/[ 　,.、。]/)
    end
  end

  def topics
    split.uniq.delete_if { |word| !Message.topic?(word) }
  end

  def self.topic?(word)
    (4..15).cover?(word.length)
  end

  def regenerate_topics
    MessageTopic.where(message: self).delete_all
    topics.each do |word|
      MessageTopic.create(message: self, topic: word) if Message.topic?(word)
    end
  end
end
