class User < ApplicationRecord
  # Include default devise modules. Others available are:
  # :confirmable, :lockable, :timeoutable, :trackable and :omniauthable
  devise :database_authenticatable, :registerable,
         :recoverable, :rememberable, :validatable

  has_many :observes, foreign_key: "from_user_id", class_name: "Observe"
  has_many :observe_users, through: :observes, source: "to_user"
  has_many :observed, foreign_key: "to_user_id", class_name: "Observe"
  has_many :observed_users, through: :observed, source: "from_user"
  has_many :subscribe_topics, class_name: 'UserSubscribeTopic'

  has_one_attached :profile_image

  validates :description, length: { maximum: 200 }

  def follow?(user)
    observe_users.include?(user)
  end

  def subscribe_topic?(topic)
    subscribe_topics.where(topic: topic).exists?
  end
end
